@@ -1,7 +1,8 @@
 package MooX::LazyRequire;
-use strictures 1;
+use strict;
+use warnings;
 
-our $VERSION = '0.001001';
+our $VERSION = '0.001002';
 $VERSION = eval $VERSION;
 
 use Carp;
